'''
Manage Server Trust Groups.
'''
from ... pyaz_utils import _call_az

def create(group_member, location, name, resource_group, trust_scope, no_wait=None):
    '''
    Create a Server Trust Group.

    Required Parameters:
    - group_member -- Managed Instance that is to be a member of the group.
                   Specify resource group, subscription id and the name of the instance.
    - location -- The location name of the Server Trust Group.
    - name -- The name of the Server Trust Group.
    - resource_group -- The resource group name
    - trust_scope -- The trust scope of the Server Trust Group.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az sql stg create", locals())


def delete(location, name, resource_group, no_wait=None, yes=None):
    '''
    Delete a Server Trust Group.

    Required Parameters:
    - location -- The location of the Server Trust Group.
    - name -- The name of the Server Trust Group.
    - resource_group -- The resource group name

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql stg delete", locals())


def show(location, name, resource_group):
    '''
    Retrieve a Server Trust Group.

    Required Parameters:
    - location -- The location of the Server Trust Group.
    - name -- The name of the Server Trust Group.
    - resource_group -- The resource group name
    '''
    return _call_az("az sql stg show", locals())


def list(resource_group, instance_name=None, location=None):
    '''
    Retrieve a list of Server Trust Groups.

    Required Parameters:
    - resource_group -- The resource group name

    Optional Parameters:
    - instance_name -- Managed Instance name.
    - location -- The location of the Server Trust Group.
    '''
    return _call_az("az sql stg list", locals())




from .... pyaz_utils import _call_az

def list(gateway_name, resource_group):
    '''
    List address pools.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway address-pool list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of an address pool.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the backend address pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway address-pool show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete an address pool.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the backend address pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network application-gateway address-pool delete", locals())


def create(gateway_name, name, resource_group, no_wait=None, servers=None):
    '''
    Create an address pool.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the backend address pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - servers -- Space-separated list of IP addresses or DNS names corresponding to backend servers.
    '''
    return _call_az("az network application-gateway address-pool create", locals())


def update(gateway_name, name, resource_group, add=None, force_string=None, no_wait=None, remove=None, servers=None, set=None):
    '''
    Update an address pool.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the backend address pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - servers -- Space-separated list of IP addresses or DNS names corresponding to backend servers.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network application-gateway address-pool update", locals())




'''
Manage template specs at subscription or resource group scope.
'''
from .. pyaz_utils import _call_az

def create(name, resource_group, description=None, display_name=None, location=None, tags=None, template_file=None, ui_form_definition=None, version=None, version_description=None, yes=None):
    '''
    Create a template spec and or template spec version.

    Required Parameters:
    - name -- The name of the template spec.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - description -- The description of the parent template spec.
    - display_name -- The display name of the template spec
    - location -- The location to store the template-spec and template-spec version(s). Cannot be changed after creation.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - template_file -- a path to a template file or Bicep file in the file system
    - ui_form_definition -- The uiFormDefinition file path in the file system for the template spec version.
    - version -- The template spec version.
    - version_description -- The description of the template spec version.
    - yes -- Do not prompt for confirmation
    '''
    return _call_az("az ts create", locals())


def update(description=None, display_name=None, name=None, resource_group=None, tags=None, template_file=None, template_spec=None, ui_form_definition=None, version=None, version_description=None, yes=None):
    '''
    Update a template spec version.

    Optional Parameters:
    - description -- The description of the parent template spec.
    - display_name -- The display name of the template spec
    - name -- The name of the template spec.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - template_file -- a path to a template file or Bicep file in the file system
    - template_spec -- The template spec resource id.
    - ui_form_definition -- The uiFormDefinition file path in the file system for the template spec version.
    - version -- The template spec version.
    - version_description -- The description of the template spec version.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az ts update", locals())


def export(output_folder, name=None, resource_group=None, template_spec=None, version=None):
    '''
    Export the specified template spec version and artifacts (if any) to the specified output folder.

    Required Parameters:
    - output_folder -- Existing folder to output export(s).

    Optional Parameters:
    - name -- The name of the template spec.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - template_spec -- The template spec resource id.
    - version -- The template spec version.
    '''
    return _call_az("az ts export", locals())


def show(name=None, resource_group=None, template_spec=None, version=None):
    '''
    Get the specified template spec or template spec version.

    Optional Parameters:
    - name -- The name of the template spec.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - template_spec -- The template spec resource id.
    - version -- The template spec version.
    '''
    return _call_az("az ts show", locals())


def list(name=None, resource_group=None):
    '''
    List template specs or template spec versions.

    Optional Parameters:
    - name -- The name of the template spec.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ts list", locals())


def delete(name=None, resource_group=None, template_spec=None, version=None, yes=None):
    '''
    Delete a specified template spec or template spec version by name or resource ID..

    Optional Parameters:
    - name -- The name of the template spec.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - template_spec -- The template spec resource id.
    - version -- The template spec version.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az ts delete", locals())




'''
Manage Azure Red Hat OpenShift 3.11 clusters.
'''
from .. pyaz_utils import _call_az
from . import monitor


def create(name, resource_group, aad_client_app_id=None, aad_client_app_secret=None, aad_tenant_id=None, compute_count=None, compute_vm_size=None, customer_admin_group_id=None, location=None, no_wait=None, subnet_prefix=None, tags=None, vnet_peer=None, vnet_prefix=None, workspace_id=None):
    '''
    Create a new Azure Red Hat OpenShift 3.11 cluster.

    Required Parameters:
    - name -- Name of the managed OpenShift cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - aad_client_app_id -- None
    - aad_client_app_secret -- None
    - aad_tenant_id -- None
    - compute_count -- None
    - compute_vm_size -- None
    - customer_admin_group_id -- None
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - subnet_prefix -- None
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vnet_peer -- None
    - vnet_prefix -- None
    - workspace_id -- None
    '''
    return _call_az("az openshift create", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete an Azure Red Hat OpenShift 3.11 cluster.

    Required Parameters:
    - name -- Name of the managed OpenShift cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az openshift delete", locals())


def scale(compute_count, name, resource_group, no_wait=None):
    '''
    Scale the compute pool in an Azure Red Hat OpenShift 3.11 cluster.

    Required Parameters:
    - compute_count -- None
    - name -- Name of the managed OpenShift cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az openshift scale", locals())


def show(name, resource_group):
    '''
    Show the details for an Azure Red Hat OpenShift 3.11 cluster.

    Required Parameters:
    - name -- Name of the managed OpenShift cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az openshift show", locals())


def list(resource_group=None):
    '''
    List Azure Red Hat OpenShift 3.11 clusters.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az openshift list", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for an Azure Red Hat OpenShift 3.11 cluster to reach a desired state.

    Required Parameters:
    - name -- Name of the managed OpenShift cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az openshift wait", locals())




from .... pyaz_utils import _call_az

def assign(audience, gateway_name, issuer, resource_group, tenant, no_wait=None):
    '''
    Assign/Update AAD(Azure Active Directory) authentication to a virtual network gateway.

    Required Parameters:
    - audience -- The AADAudience ID of the VirtualNetworkGateway.
    - gateway_name -- Virtual network gateway name
    - issuer -- The AADIssuer URI of the VirtualNetworkGateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - tenant -- The AADTenant URI of the VirtualNetworkGateway.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network vnet-gateway aad assign", locals())


def show(gateway_name, resource_group):
    '''
    Show AAD(Azure Active Directory) authentication of a virtual network gateway

    Required Parameters:
    - gateway_name -- Virtual network gateway name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vnet-gateway aad show", locals())


def remove(gateway_name, resource_group, no_wait=None):
    '''
    Remove AAD(Azure Active Directory) authentication from a virtual network gateway

    Required Parameters:
    - gateway_name -- Virtual network gateway name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network vnet-gateway aad remove", locals())




'''
Manage encryption for an Azure Media Services account.
'''
from .... pyaz_utils import _call_az

def show(account_name, resource_group):
    '''
    Show the details of encryption settings for an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams account encryption show", locals())


def set(account_name, key_type, resource_group, current_key_id=None, key_identifier=None):
    '''
    Set the encryption settings for an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - key_type -- The encryption key source (provider). Allowed values: SystemKey, CustomerKey.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - current_key_id -- The current key used to encrypt the Media Services account, including the key version.
    - key_identifier -- The URL of the Key Vault key used to encrypt the account. The key may either be versioned (for example https://vault/keys/mykey/version1) or reference a key without a version (for example https://vault/keys/mykey).
    '''
    return _call_az("az ams account encryption set", locals())




'''
Manage Azure API Management Product's.
'''
from ... pyaz_utils import _call_az
from . import api


def list(resource_group, service_name):
    '''
    Lists a collection of products in the specified service instance.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the api management service instance
    '''
    return _call_az("az apim product list", locals())


def show(product_id, resource_group, service_name):
    '''
    Gets the details of the product specified by its identifier.

    Required Parameters:
    - product_id -- Product identifier. Must be unique in the current API Management service instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the api management service instance
    '''
    return _call_az("az apim product show", locals())


def create(product_name, resource_group, service_name, approval_required=None, description=None, legal_terms=None, no_wait=None, product_id=None, state=None, subscription_required=None, subscriptions_limit=None):
    '''
    Creates a product.

    Required Parameters:
    - product_name -- Product name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the api management service instance

    Optional Parameters:
    - approval_required -- whether subscription approval is required. If false, new subscriptions will be approved automatically enabling developers to call the product’s APIs immediately after subscribing. If true, administrators must manually approve the subscription before the developer can any of the product’s APIs. Can be present only if subscriptionRequired property is present and has a value of false.
    - description -- Product description. May include HTML formatting tags.
    - legal_terms -- Product terms of use. Developers trying to subscribe to the product will be presented and required to accept these terms before they can complete the subscription process.
    - no_wait -- Do not wait for the long-running operation to finish.
    - product_id -- Product identifier. Must be unique in the current API Management service instance.
    - state -- whether product is published or not. Published products are discoverable by users of developer portal. Non published products are visible only to administrators. Default state of Product is notPublished. Possible values include: 'notPublished', 'published'
    - subscription_required -- Whether a product subscription is required for accessing APIs included in this product.
    - subscriptions_limit -- Whether the number of subscriptions a user can have to this product at the same time. Set to null or omit to allow unlimited per user subscriptions. Can be present only if subscriptionRequired property is present and has a value of false.
    '''
    return _call_az("az apim product create", locals())


def update(product_id, resource_group, service_name, add=None, approval_required=None, description=None, force_string=None, if_match=None, legal_terms=None, no_wait=None, product_name=None, remove=None, set=None, state=None, subscription_required=None, subscriptions_limit=None):
    '''
    Update existing product details.

    Required Parameters:
    - product_id -- Product identifier. Must be unique in the current API Management service instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the api management service instance

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - approval_required -- whether subscription approval is required. If false, new subscriptions will be approved automatically enabling developers to call the product’s APIs immediately after subscribing. If true, administrators must manually approve the subscription before the developer can any of the product’s APIs. Can be present only if subscriptionRequired property is present and has a value of false.
    - description -- Product description. May include HTML formatting tags.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - if_match -- ETag of the Entity.
    - legal_terms -- Product terms of use. Developers trying to subscribe to the product will be presented and required to accept these terms before they can complete the subscription process.
    - no_wait -- Do not wait for the long-running operation to finish.
    - product_name -- Product name.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - state -- whether product is published or not. Published products are discoverable by users of developer portal. Non published products are visible only to administrators. Default state of Product is notPublished. Possible values include: 'notPublished', 'published'
    - subscription_required -- Whether a product subscription is required for accessing APIs included in this product.
    - subscriptions_limit -- Whether the number of subscriptions a user can have to this product at the same time. Set to null or omit to allow unlimited per user subscriptions. Can be present only if subscriptionRequired property is present and has a value of false.
    '''
    return _call_az("az apim product update", locals())


def delete(product_id, resource_group, service_name, delete_subscriptions=None, if_match=None, no_wait=None, yes=None):
    '''
    Delete product.

    Required Parameters:
    - product_id -- Product identifier. Must be unique in the current API Management service instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the api management service instance

    Optional Parameters:
    - delete_subscriptions -- Delete existing subscriptions associated with the product or not.
    - if_match -- ETag of the Entity.
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az apim product delete", locals())


def wait(product_id, resource_group, service_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of an apim product is met.

    Required Parameters:
    - product_id -- Product identifier. Must be unique in the current API Management service instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the api management service instance

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az apim product wait", locals())




from ... pyaz_utils import _call_az

def create(name, registry, description=None, gateway=None, repository=None, resource_group=None):
    '''
    Create a scope map for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the scope map.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - description -- Description for the scope map. Maximum 256 characters are allowed.
    - gateway -- gateway permissions. Use the format "--gateway GATEWAY [ACTION1 ACTION2 ...]" per flag. Valid actions are {'config/read', 'message/write', 'config/write', 'message/read'}
    - repository -- repository permissions. Use the format "--repository REPO [ACTION1 ACTION2 ...]" per flag. Valid actions are {'content/read', 'content/write', 'metadata/write', 'metadata/read', 'content/delete'}
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr scope-map create", locals())


def delete(name, registry, resource_group=None, yes=None):
    '''
    Delete a scope map for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the scope map.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az acr scope-map delete", locals())


def update(name, registry, add_gateway=None, add_repository=None, description=None, remove_gateway=None, remove_repository=None, resource_group=None):
    '''
    Update a scope map for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the scope map.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - add_gateway -- gateway permissions to be added. Use the format "--add-gateway GATEWAY [ACTION1 ACTION2 ...]" per flag. Valid actions are {'config/read', 'message/write', 'config/write', 'message/read'}
    - add_repository -- repository permissions to be added. Use the format "--add-repository REPO [ACTION1 ACTION2 ...]" per flag. Valid actions are {'content/read', 'content/write', 'metadata/write', 'metadata/read', 'content/delete'}
    - description -- Description for the scope map. Maximum 256 characters are allowed.
    - remove_gateway -- gateway permissions to be removed. Use the format "--remove-gateway GATEWAY [ACTION1 ACTION2 ...]" per flag. Valid actions are {'config/read', 'message/write', 'config/write', 'message/read'}
    - remove_repository -- respsitory permissions to be removed. Use the format "--remove-repository REPO [ACTION1 ACTION2 ...]" per flag. Valid actions are {'content/read', 'content/write', 'metadata/write', 'metadata/read', 'content/delete'}
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr scope-map update", locals())


def show(name, registry, resource_group=None):
    '''
    Show details and attributes of a scope map for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the scope map.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr scope-map show", locals())


def list(registry, resource_group=None):
    '''
    List all scope maps for an Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr scope-map list", locals())




from .... pyaz_utils import _call_az

def start(name, type, no_wait=None, resource_group=None):
    '''
    Validate/Begin migrating a storage account to enable hierarchical namespace.

    Required Parameters:
    - name -- The storage account name.
    - type -- Start a validation request for migration or start a migration request

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account hns-migration start", locals())


def stop(name, no_wait=None, resource_group=None):
    '''
    Stop the enabling hierarchical namespace migration of a storage account.

    Required Parameters:
    - name -- The storage account name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account hns-migration stop", locals())




from ..... pyaz_utils import _call_az

def show(circuit_name, name, peering_name, resource_group):
    '''
    

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - name -- Name of the peering peer-connection.
    - peering_name -- Name of BGP peering (i.e. AzurePrivatePeering).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route peering peer-connection show", locals())


def list(circuit_name, peering_name, resource_group):
    '''
    

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - peering_name -- Name of BGP peering (i.e. AzurePrivatePeering).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route peering peer-connection list", locals())




from .... pyaz_utils import _call_az

def set(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, expiry_time=None, policy_mode=None, sas_token=None, timeout=None):
    '''
    Set blob's immutability policy.

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - expiry_time -- expiration UTC datetime in (Y-m-d'T'H:M:S'Z')
    - policy_mode -- Lock or Unlock the policy
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob immutability-policy set", locals())


def delete(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Delete blob's immutability policy.

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob immutability-policy delete", locals())




'''
Manage resource provider feature registrations.
'''
from ... pyaz_utils import _call_az

def list(namespace=None):
    '''
    List feature registrations.

    Optional Parameters:
    - namespace -- the resource namespace, aka 'provider'
    '''
    return _call_az("az feature registration list", locals())


def show(name, provider_namespace):
    '''
    

    Required Parameters:
    - name -- the feature name
    - provider_namespace -- The provider namespace.
    '''
    return _call_az("az feature registration show", locals())


def create(name, namespace):
    '''
    Create a feature registration.

    Required Parameters:
    - name -- the feature name
    - namespace -- the resource namespace, aka 'provider'
    '''
    return _call_az("az feature registration create", locals())


def delete(name, namespace, yes=None):
    '''
    Delete a feature registration.

    Required Parameters:
    - name -- the feature name
    - namespace -- the resource namespace, aka 'provider'

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az feature registration delete", locals())




from ..... pyaz_utils import _call_az

def add(ip_address, lb_name, name, pool_name, resource_group, subnet=None, vnet=None):
    '''
    Add one backend address into the load balance backend address pool.

    Required Parameters:
    - ip_address -- Ip Address within the Virtual Network.
    - lb_name -- The load balancer name.
    - name -- Name of the backend address.
    - pool_name -- The name of the backend address pool. If only one exists, omit to use as default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - subnet -- Name or Id of the existing subnet.(If name is provided, vnet is also required;If id, vnet is not required)
    - vnet -- Name or Id of the virtual network.
    '''
    return _call_az("az network lb address-pool address add", locals())


def remove(lb_name, name, pool_name, resource_group):
    '''
    Remove one backend address from the load balance backend address pool.

    Required Parameters:
    - lb_name -- The load balancer name.
    - name -- Name of the backend address.
    - pool_name -- The name of the backend address pool. If only one exists, omit to use as default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network lb address-pool address remove", locals())


def list(lb_name, pool_name, resource_group):
    '''
    List all backend addresses of the load balance backend address pool.

    Required Parameters:
    - lb_name -- The load balancer name.
    - pool_name -- The name of the backend address pool. If only one exists, omit to use as default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network lb address-pool address list", locals())




from ... pyaz_utils import _call_az

def create(name, resource_group, schedule_entries):
    '''
    Create patching schedule for Redis cache.

    Required Parameters:
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schedule_entries -- List of Patch schedule entries. Example Value:[{"dayOfWeek":"Monday","startHourUtc":"00","maintenanceWindow":"PT5H"}]
    '''
    return _call_az("az redis patch-schedule create", locals())


def update(name, resource_group, schedule_entries):
    '''
    Update the patching schedule for Redis cache.

    Required Parameters:
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schedule_entries -- List of Patch schedule entries. Example Value:[{"dayOfWeek":"Monday","startHourUtc":"00","maintenanceWindow":"PT5H"}]
    '''
    return _call_az("az redis patch-schedule update", locals())


def delete(name, resource_group):
    '''
    Deletes the patching schedule of a redis cache.

    Required Parameters:
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az redis patch-schedule delete", locals())


def show(name, resource_group):
    '''
    Gets the patching schedule of a redis cache.

    Required Parameters:
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az redis patch-schedule show", locals())




from ... pyaz_utils import _call_az
from . import rule


def create(name, resource_group, location=None, tags=None):
    '''
    Create a route filter.

    Required Parameters:
    - name -- Name of the route filter.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network route-filter create", locals())


def list(resource_group=None):
    '''
    List route filters.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network route-filter list", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a route filter.

    Required Parameters:
    - name -- Name of the route filter.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Expands referenced express route bgp peering resources.
    '''
    return _call_az("az network route-filter show", locals())


def delete(name, resource_group):
    '''
    Delete a route filter.

    Required Parameters:
    - name -- Name of the route filter.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network route-filter delete", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a route filter.

    Required Parameters:
    - name -- Name of the route filter.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network route-filter update", locals())




'''
Manage the steps.
'''
from ... pyaz_utils import _call_az

def create(resource_group, duration=None, location=None, step=None, step_name=None, tags=None):
    '''
    Creates the step.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - duration -- The duration of the wait step in ISO 8601 format.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - step -- The step object, specify either the path to a json file or provide a json string that forms the step resource. The json is expected to be of the same format as the output of the relevant `az deploymentmanager step show` command
    - step_name -- The name of the step
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az deploymentmanager step create", locals())


def delete(resource_group, step_name):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - step_name -- The name of the step
    '''
    return _call_az("az deploymentmanager step delete", locals())


def show(resource_group, step_name):
    '''
    Get the details of the step.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - step_name -- The name of the step
    '''
    return _call_az("az deploymentmanager step show", locals())


def list(resource_group):
    '''
    List all steps in a resource group.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az deploymentmanager step list", locals())


def update(resource_group, step_name, add=None, duration=None, force_string=None, remove=None, set=None, step=None, tags=None):
    '''
    Updates the step.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - step_name -- The name of the step

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - duration -- The duration of the wait step in ISO 8601 format.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - step -- The step object, specify either the path to a json file or provide a json string that forms the step resource. The json is expected to be of the same format as the output of the relevant `az deploymentmanager step show` command
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az deploymentmanager step update", locals())




'''
Display billing agreement
'''
from ... pyaz_utils import _call_az

def list(account_name, expand=None):
    '''
    List the agreements for a billing account.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - expand -- May be used to expand the participants.
    '''
    return _call_az("az billing agreement list", locals())


def show(account_name, name, expand=None):
    '''
    Get an agreement by ID.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies an agreement.

    Optional Parameters:
    - expand -- May be used to expand the participants.
    '''
    return _call_az("az billing agreement show", locals())




from .... pyaz_utils import _call_az

def list(dps_name, resource_group):
    '''
    List all shared access policies in an Azure IoT Hub device provisioning service.

    Required Parameters:
    - dps_name -- IoT Provisioning Service name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot dps access-policy list", locals())


def show(access_policy_name, dps_name, resource_group):
    '''
    Show details of a shared access policies in an Azure IoT Hub device provisioning service.

    Required Parameters:
    - access_policy_name -- A friendly name for DPS access policy.
    - dps_name -- IoT Provisioning Service name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot dps access-policy show", locals())


def create(access_policy_name, dps_name, resource_group, rights, no_wait=None, primary_key=None, secondary_key=None):
    '''
    Create a new shared access policy in an Azure IoT Hub device provisioning service.

    Required Parameters:
    - access_policy_name -- A friendly name for DPS access policy.
    - dps_name -- IoT Provisioning Service name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rights -- Access rights for the IoT provisioning service. Use space-separated list for multiple rights.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - primary_key -- Primary SAS key value.
    - secondary_key -- Secondary SAS key value.
    '''
    return _call_az("az iot dps access-policy create", locals())


def update(access_policy_name, dps_name, resource_group, no_wait=None, primary_key=None, rights=None, secondary_key=None):
    '''
    Update a shared access policy in an Azure IoT Hub device provisioning service.

    Required Parameters:
    - access_policy_name -- A friendly name for DPS access policy.
    - dps_name -- IoT Provisioning Service name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - primary_key -- Primary SAS key value.
    - rights -- Access rights for the IoT provisioning service. Use space-separated list for multiple rights.
    - secondary_key -- Secondary SAS key value.
    '''
    return _call_az("az iot dps access-policy update", locals())


def delete(access_policy_name, dps_name, resource_group, no_wait=None):
    '''
    Delete a shared access policies in an Azure IoT Hub device provisioning service.

    Required Parameters:
    - access_policy_name -- A friendly name for DPS access policy.
    - dps_name -- IoT Provisioning Service name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az iot dps access-policy delete", locals())




from ... pyaz_utils import _call_az
from . import categories, subscription


def create(name, resource, event_hub=None, event_hub_rule=None, export_to_resource_specific=None, logs=None, metrics=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None, storage_account=None, workspace=None):
    '''
    Create diagnostic settings for the specified resource.

    Required Parameters:
    - name -- None
    - resource -- Name or ID of the target resource.

    Optional Parameters:
    - event_hub -- None
    - event_hub_rule -- None
    - export_to_resource_specific -- Indicate that the export to LA must be done to a resource specific table, a.k.a. dedicated or fixed schema table, as opposed to the default dynamic schema table called AzureDiagnostics. This argument is effective only when the argument --workspace is also given.
    - logs -- None
    - metrics -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_namespace -- Target resource provider namespace.
    - resource_parent -- Target resource parent path, if applicable.
    - resource_type -- Target resource type. Can also accept namespace/type format (Ex: 'Microsoft.Compute/virtualMachines')
    - storage_account -- None
    - workspace -- None
    '''
    return _call_az("az monitor diagnostic-settings create", locals())


def show(name, resource, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None):
    '''
    

    Required Parameters:
    - name -- The name of the diagnostic setting.
    - resource -- Name or ID of the target resource.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_namespace -- Target resource provider namespace.
    - resource_parent -- Target resource parent path, if applicable.
    - resource_type -- Target resource type. Can also accept namespace/type format (Ex: 'Microsoft.Compute/virtualMachines')
    '''
    return _call_az("az monitor diagnostic-settings show", locals())


def list(resource, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None):
    '''
    

    Required Parameters:
    - resource -- Name or ID of the target resource.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_namespace -- Target resource provider namespace.
    - resource_parent -- Target resource parent path, if applicable.
    - resource_type -- Target resource type. Can also accept namespace/type format (Ex: 'Microsoft.Compute/virtualMachines')
    '''
    return _call_az("az monitor diagnostic-settings list", locals())


def delete(name, resource, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None):
    '''
    

    Required Parameters:
    - name -- The name of the diagnostic setting.
    - resource -- Name or ID of the target resource.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_namespace -- Target resource provider namespace.
    - resource_parent -- Target resource parent path, if applicable.
    - resource_type -- Target resource type. Can also accept namespace/type format (Ex: 'Microsoft.Compute/virtualMachines')
    '''
    return _call_az("az monitor diagnostic-settings delete", locals())


def update(name, resource, add=None, force_string=None, remove=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None, set=None):
    '''
    Update diagnostic settings.

    Required Parameters:
    - name -- The name of the diagnostic setting.
    - resource -- Name or ID of the target resource.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_namespace -- Target resource provider namespace.
    - resource_parent -- Target resource parent path, if applicable.
    - resource_type -- Target resource type. Can also accept namespace/type format (Ex: 'Microsoft.Compute/virtualMachines')
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az monitor diagnostic-settings update", locals())




'''
Manage SQL servers.
'''
from ... pyaz_utils import _call_az
from . import ad_admin, ad_only_auth, audit_policy, conn_policy, dns_alias, firewall_rule, key, outbound_firewall_rule, tde_key, vnet_rule


def create(name, resource_group, admin_password=None, admin_user=None, assign_identity=None, enable_ad_only_auth=None, enable_public_network=None, external_admin_name=None, external_admin_principal_type=None, external_admin_sid=None, identity_type=None, key_id=None, location=None, minimal_tls_version=None, no_wait=None, primary_user_assigned_identity_id=None, restrict_outbound_network_access=None, user_assigned_identity_id=None):
    '''
    Create a server.

    Required Parameters:
    - name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - admin_password -- The administrator login password (required for server creation).
    - admin_user -- Administrator username for the server. Once created it cannot be changed.
    - assign_identity -- Generate and assign an Azure Active Directory Identity for this server for use with key management services like Azure KeyVault.
    - enable_ad_only_auth -- Enable Azure Active Directory Only Authentication for this server.
    - enable_public_network -- Set whether public network access to server is allowed or not. When false,only connections made through Private Links can reach this server.
    - external_admin_name -- Display name of the Azure AD administrator user, group or application.
    - external_admin_principal_type -- User, Group or Application
    - external_admin_sid -- The unique ID of the Azure AD administrator. Object Id for User or Group, Client Id for Applications
    - identity_type -- Type of Identity to be used. Possible values are SystemAsssigned,UserAssigned, SystemAssigned,UserAssigned and None.
    - key_id -- The key vault URI for encryption.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - minimal_tls_version -- The minimal TLS version enforced by the sql server for inbound connections.
    - no_wait -- Do not wait for the long-running operation to finish.
    - primary_user_assigned_identity_id -- The ID of the primary user managed identity.
    - restrict_outbound_network_access -- Set whether outbound network access to server is restricted or not. When true,the outbound connections from the server will be restricted.
    - user_assigned_identity_id -- Generate and assign an User Managed Identity(UMI) for this server.
    '''
    return _call_az("az sql server create", locals())


def delete(name, resource_group, yes=None):
    '''
    

    Required Parameters:
    - name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql server delete", locals())


def show(name, resource_group, expand_ad_admin=None):
    '''
    

    Required Parameters:
    - name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand_ad_admin -- Expand the Active Directory Administrator for the server.
    '''
    return _call_az("az sql server show", locals())


def list(expand_ad_admin=None, resource_group=None):
    '''
    List available servers.

    Optional Parameters:
    - expand_ad_admin -- Expand the Active Directory Administrator for the server.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql server list", locals())


def update(name, resource_group, add=None, admin_password=None, assign_identity=None, enable_public_network=None, force_string=None, identity_type=None, key_id=None, minimal_tls_version=None, no_wait=None, primary_user_assigned_identity_id=None, remove=None, restrict_outbound_network_access=None, set=None, user_assigned_identity_id=None):
    '''
    Update a server.

    Required Parameters:
    - name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - admin_password -- The administrator login password.
    - assign_identity -- Generate and assign an Azure Active Directory Identity for this server for use with key management services like Azure KeyVault.
    - enable_public_network -- Set whether public network access to server is allowed or not. When false,only connections made through Private Links can reach this server.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - identity_type -- Type of Identity to be used. Possible values are SystemAsssigned,UserAssigned, SystemAssigned,UserAssigned and None.
    - key_id -- The key vault URI for encryption.
    - minimal_tls_version -- The minimal TLS version enforced by the sql server for inbound connections.
    - no_wait -- Do not wait for the long-running operation to finish.
    - primary_user_assigned_identity_id -- The ID of the primary user managed identity.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - restrict_outbound_network_access -- Set whether outbound network access to server is restricted or not. When true,the outbound connections from the server will be restricted.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - user_assigned_identity_id -- Generate and assign an User Managed Identity(UMI) for this server.
    '''
    return _call_az("az sql server update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the SQL server is met.

    Required Parameters:
    - name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - expand -- The child resources to include in the response.
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az sql server wait", locals())


def list_usages(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql server list-usages", locals())




'''
Manage deployment operations.
'''
from .... pyaz_utils import _call_az

def list(name, resource_group, top=None):
    '''
    

    Required Parameters:
    - name -- The deployment name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - top -- The number of results to return.
    '''
    return _call_az("az group deployment operation list", locals())


def show(name, operation_ids, resource_group):
    '''
    

    Required Parameters:
    - name -- The deployment name.
    - operation_ids -- A list of operation ids to show
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az group deployment operation show", locals())




from ...... pyaz_utils import _call_az

def add(match_variables, name, operator, policy_name, resource_group, values, negate=None, transforms=None):
    '''
    A match condition to an application gateway WAF policy custom rule.

    Required Parameters:
    - match_variables -- Space-separated list of variables to use when matching. Variable values: RemoteAddr, RequestMethod, QueryString, PostArgs, RequestUri, RequestHeaders, RequestBody, RequestCookies
    - name -- Name of the WAF policy rule.
    - operator -- Operator for matching.
    - policy_name -- The name of the application gateway WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - values -- Space-separated list of values to match.

    Optional Parameters:
    - negate -- Match the negative of the condition.
    - transforms -- Space-separated list of transforms to apply when matching.
    '''
    return _call_az("az network application-gateway waf-policy custom-rule match-condition add", locals())


def list(name, policy_name, resource_group):
    '''
    List application gateway WAF policy custom rule match conditions.

    Required Parameters:
    - name -- Name of the WAF policy rule.
    - policy_name -- The name of the application gateway WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway waf-policy custom-rule match-condition list", locals())


def remove(index, name, policy_name, resource_group):
    '''
    Remove a match condition from an application gateway WAF policy custom rule.

    Required Parameters:
    - index -- Index of the match condition to remove.
    - name -- Name of the WAF policy rule.
    - policy_name -- The name of the application gateway WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway waf-policy custom-rule match-condition remove", locals())




from ... pyaz_utils import _call_az
from . import install, permissions


def create(name, registry, audit_logs_enabled=None, client_tokens=None, log_level=None, mode=None, parent=None, repository=None, resource_group=None, sync_message_ttl=None, sync_schedule=None, sync_token=None, sync_window=None):
    '''
    Create a connected registry for an Azure Container Registry.

    Required Parameters:
    - name -- Name for the connected registry. Name must be between 5 to 40 character long, start with a letter and contain only alphanumeric characters (including ‘_’ or ‘-’). Name must be unique under the Cloud ACR hierarchy.
    - registry -- The login server of the Cloud ACR registry. Must be the FQDN to support also Azure Stack.

    Optional Parameters:
    - audit_logs_enabled -- Indicate whether audit log synchronization is enabled. It is enabled by default.
    - client_tokens -- Specify the client access to the repositories in the connected registry. It can be in the format [TOKEN_NAME01] [TOKEN_NAME02]...
    - log_level -- Set the log level for logging on the instance. Accepted log levels are Debug, Information, Warning, Error, and None.
    - mode -- Determine the access it will have when synchronized.
    - parent -- The name of the parent connected registry.
    - repository -- Specify the repositories that need to be sync to the connected registry. It can be in the format [REPO01] [REPO02]...
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sync_message_ttl -- Determine how long the sync messages will be kept in the cloud. Uses ISO 8601 duration format.
    - sync_schedule -- Optional parameter to define the sync schedule. Uses cron expression to determine the schedule. If not specified, the instance is considered always online and attempts to sync every minute.
    - sync_token -- Specifies the sync token used to synchronize the connected registry with its parent. It most have only repo permissions and at least the actions required for its mode. It can include access for multiple repositories.
    - sync_window -- Required parameter if --sync-schedule is present. Used to determine the schedule duration. Uses ISO 8601 duration format.
    '''
    return _call_az("az acr connected-registry create", locals())


def delete(name, registry, cleanup=None, resource_group=None, yes=None):
    '''
    Delete a connected registry from Azure Container Registry.

    Required Parameters:
    - name -- Name for the connected registry. Name must be between 5 to 40 character long, start with a letter and contain only alphanumeric characters (including ‘_’ or ‘-’). Name must be unique under the Cloud ACR hierarchy.
    - registry -- The login server of the Cloud ACR registry. Must be the FQDN to support also Azure Stack.

    Optional Parameters:
    - cleanup -- It will aslo delete the sync token and the scope map resources.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az acr connected-registry delete", locals())


def show(name, registry, resource_group=None):
    '''
    Show connected registry details.

    Required Parameters:
    - name -- Name for the connected registry. Name must be between 5 to 40 character long, start with a letter and contain only alphanumeric characters (including ‘_’ or ‘-’). Name must be unique under the Cloud ACR hierarchy.
    - registry -- The login server of the Cloud ACR registry. Must be the FQDN to support also Azure Stack.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr connected-registry show", locals())


def deactivate(name, registry, resource_group=None, yes=None):
    '''
    Deactivate a connected registry from Azure Container Registry.

    Required Parameters:
    - name -- Name for the connected registry. Name must be between 5 to 40 character long, start with a letter and contain only alphanumeric characters (including ‘_’ or ‘-’). Name must be unique under the Cloud ACR hierarchy.
    - registry -- The login server of the Cloud ACR registry. Must be the FQDN to support also Azure Stack.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az acr connected-registry deactivate", locals())


def update(name, registry, add_client_tokens=None, audit_logs_enabled=None, log_level=None, remove_client_tokens=None, resource_group=None, sync_message_ttl=None, sync_schedule=None, sync_window=None):
    '''
    Update a connected registry for an Azure Container Registry.

    Required Parameters:
    - name -- Name for the connected registry. Name must be between 5 to 40 character long, start with a letter and contain only alphanumeric characters (including ‘_’ or ‘-’). Name must be unique under the Cloud ACR hierarchy.
    - registry -- The login server of the Cloud ACR registry. Must be the FQDN to support also Azure Stack.

    Optional Parameters:
    - add_client_tokens -- Client tokens to be added. Use the format "--add-client-tokens [TOKEN_NAME1 TOKEN_NAME2 ...]" per token id.
    - audit_logs_enabled -- Indicate whether audit log synchronization is enabled. It is enabled by default.
    - log_level -- Set the log level for logging on the instance. Accepted log levels are Debug, Information, Warning, Error, and None.
    - remove_client_tokens -- Client tokens to be removed. Use the format "--remove-client-tokens [TOKEN_NAME1 TOKEN_NAME2 ...]" per token id.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sync_message_ttl -- Determine how long the sync messages will be kept in the cloud. Uses ISO 8601 duration format.
    - sync_schedule -- Optional parameter to define the sync schedule. Uses cron expression to determine the schedule. If not specified, the instance is considered always online and attempts to sync every minute.
    - sync_window -- Used to determine the schedule duration. Uses ISO 8601 duration format.
    '''
    return _call_az("az acr connected-registry update", locals())


def get_settings(name, parent_protocol, registry, generate_password=None, resource_group=None, yes=None):
    '''
    Retrieve information required to activate a connected registry, and creates or rotates the sync token credentials.

    Required Parameters:
    - name -- Name for the connected registry. Name must be between 5 to 40 character long, start with a letter and contain only alphanumeric characters (including ‘_’ or ‘-’). Name must be unique under the Cloud ACR hierarchy.
    - parent_protocol -- Specify the protocol used to communicate with its parent.
    - registry -- The login server of the Cloud ACR registry. Must be the FQDN to support also Azure Stack.

    Optional Parameters:
    - generate_password -- Select which password you want to generate, and it is required to retrieve the password from the sync token.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az acr connected-registry get-settings", locals())


def list(registry, no_children=None, parent=None, resource_group=None):
    '''
    List all the connected registries under the current parent registry.

    Required Parameters:
    - registry -- The login server of the Cloud ACR registry. Must be the FQDN to support also Azure Stack.

    Optional Parameters:
    - no_children -- Used to remove all children from the list.
    - parent -- The name of the parent connected registry.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr connected-registry list", locals())


def list_client_tokens(name, registry, resource_group=None):
    '''
    List all the client tokens associated to a specific connected registries.

    Required Parameters:
    - name -- Name for the connected registry. Name must be between 5 to 40 character long, start with a letter and contain only alphanumeric characters (including ‘_’ or ‘-’). Name must be unique under the Cloud ACR hierarchy.
    - registry -- The login server of the Cloud ACR registry. Must be the FQDN to support also Azure Stack.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr connected-registry list-client-tokens", locals())


def repo(name, registry, add=None, remove=None, resource_group=None):
    '''
    Update all the necessary connected registry sync scope maps repository permissions.

    Required Parameters:
    - name -- Name for the connected registry. Name must be between 5 to 40 character long, start with a letter and contain only alphanumeric characters (including ‘_’ or ‘-’). Name must be unique under the Cloud ACR hierarchy.
    - registry -- The login server of the Cloud ACR registry. Must be the FQDN to support also Azure Stack.

    Optional Parameters:
    - add -- repository permissions to be added to the targeted connected registry and it's ancestors sync scope maps. Use the format "--add [REPO1 REPO2 ...]" per flag. Valid actions are {'content/read', 'content/write', 'metadata/write', 'metadata/read', 'content/delete'}
    - remove -- respsitory permissions to be removed from the targeted connected registry and it's succesors sync scope maps. Use the format "--remove [REPO1 REPO2 ...]" per flag. Valid actions are {'content/read', 'content/write', 'metadata/write', 'metadata/read', 'content/delete'}
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr connected-registry repo", locals())




'''
Manage Azure resources.
'''
from .. pyaz_utils import _call_az
from . import link, lock


def create(properties, api_version=None, id=None, is_full_object=None, latest_include_preview=None, location=None, name=None, namespace=None, parent=None, resource_group=None, resource_type=None):
    '''
    create a resource.

    Required Parameters:
    - properties -- a JSON-formatted string containing resource properties

    Optional Parameters:
    - api_version -- The api version of the resource (omit for the latest stable version)
    - id -- Resource ID.
    - is_full_object -- Indicate that the properties object includes other options such as location, tags, sku, and/or plan.
    - latest_include_preview -- Indicate that the latest api-version will be used regardless of whether it is preview version (like 2020-01-01-preview) or not. For example, if the supported api-version of resource provider is 2020-01-01-preview and 2019-01-01: when passing in this parameter it will take the latest version 2020-01-01-preview, otherwise it will take the latest stable version 2019-01-01 without passing in this parameter
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The resource name. (Ex: myC)
    - namespace -- Provider namespace (Ex: 'Microsoft.Provider')
    - parent -- The parent path (Ex: 'resA/myA/resB/myB')
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type (Ex: 'resC'). Can also accept namespace/type format (Ex: 'Microsoft.Provider/resC')
    '''
    return _call_az("az resource create", locals())


def delete(api_version=None, ids=None, latest_include_preview=None, name=None, namespace=None, parent=None, resource_group=None, resource_type=None):
    '''
    Delete a resource.

    Optional Parameters:
    - api_version -- The api version of the resource (omit for the latest stable version)
    - ids -- One or more resource IDs (space-delimited). If provided, no other "Resource Id" arguments should be specified.
    - latest_include_preview -- Indicate that the latest api-version will be used regardless of whether it is preview version (like 2020-01-01-preview) or not. For example, if the supported api-version of resource provider is 2020-01-01-preview and 2019-01-01: when passing in this parameter it will take the latest version 2020-01-01-preview, otherwise it will take the latest stable version 2019-01-01 without passing in this parameter
    - name -- The resource name. (Ex: myC)
    - namespace -- Provider namespace (Ex: 'Microsoft.Provider')
    - parent -- The parent path (Ex: 'resA/myA/resB/myB')
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type (Ex: 'resC'). Can also accept namespace/type format (Ex: 'Microsoft.Provider/resC')
    '''
    return _call_az("az resource delete", locals())


def show(api_version=None, ids=None, include_response_body=None, latest_include_preview=None, name=None, namespace=None, parent=None, resource_group=None, resource_type=None):
    '''
    Get the details of a resource.

    Optional Parameters:
    - api_version -- The api version of the resource (omit for the latest stable version)
    - ids -- One or more resource IDs (space-delimited). If provided, no other "Resource Id" arguments should be specified.
    - include_response_body -- Use if the default command output doesn't capture all of the property data.
    - latest_include_preview -- Indicate that the latest api-version will be used regardless of whether it is preview version (like 2020-01-01-preview) or not. For example, if the supported api-version of resource provider is 2020-01-01-preview and 2019-01-01: when passing in this parameter it will take the latest version 2020-01-01-preview, otherwise it will take the latest stable version 2019-01-01 without passing in this parameter
    - name -- The resource name. (Ex: myC)
    - namespace -- Provider namespace (Ex: 'Microsoft.Provider')
    - parent -- The parent path (Ex: 'resA/myA/resB/myB')
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type (Ex: 'resC'). Can also accept namespace/type format (Ex: 'Microsoft.Provider/resC')
    '''
    return _call_az("az resource show", locals())


def list(location=None, name=None, namespace=None, resource_group=None, resource_type=None, tag=None):
    '''
    List resources.

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The resource name. (Ex: myC)
    - namespace -- Provider namespace (Ex: 'Microsoft.Provider')
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type (Ex: 'resC'). Can also accept namespace/type format (Ex: 'Microsoft.Provider/resC')
    - tag -- a single tag in 'key[=value]' format. Use '' to clear existing tags.
    '''
    return _call_az("az resource list", locals())


def tag(tags, api_version=None, ids=None, is_incremental=None, latest_include_preview=None, name=None, namespace=None, parent=None, resource_group=None, resource_type=None):
    '''
    Tag a resource.

    Required Parameters:
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.

    Optional Parameters:
    - api_version -- The api version of the resource (omit for the latest stable version)
    - ids -- One or more resource IDs (space-delimited). If provided, no other "Resource Id" arguments should be specified.
    - is_incremental -- The option to add tags incrementally without deleting the original tags. If the key of new tag and original tag are duplicated, the original value will be overwritten.
    - latest_include_preview -- Indicate that the latest api-version will be used regardless of whether it is preview version (like 2020-01-01-preview) or not. For example, if the supported api-version of resource provider is 2020-01-01-preview and 2019-01-01: when passing in this parameter it will take the latest version 2020-01-01-preview, otherwise it will take the latest stable version 2019-01-01 without passing in this parameter
    - name -- The resource name. (Ex: myC)
    - namespace -- Provider namespace (Ex: 'Microsoft.Provider')
    - parent -- The parent path (Ex: 'resA/myA/resB/myB')
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type (Ex: 'resC'). Can also accept namespace/type format (Ex: 'Microsoft.Provider/resC')
    '''
    return _call_az("az resource tag", locals())


def move(destination_group, ids, destination_subscription_id=None):
    '''
    

    Required Parameters:
    - destination_group -- the destination resource group name
    - ids -- the space-separated resource ids to be moved

    Optional Parameters:
    - destination_subscription_id -- the destination subscription identifier
    '''
    return _call_az("az resource move", locals())


def invoke_action(action, api_version=None, ids=None, latest_include_preview=None, name=None, namespace=None, parent=None, request_body=None, resource_group=None, resource_type=None):
    '''
    Invoke an action on the resource.

    Required Parameters:
    - action -- The action that will be invoked on the specified resource

    Optional Parameters:
    - api_version -- The api version of the resource (omit for the latest stable version)
    - ids -- One or more resource IDs (space-delimited). If provided, no other "Resource Id" arguments should be specified.
    - latest_include_preview -- Indicate that the latest api-version will be used regardless of whether it is preview version (like 2020-01-01-preview) or not. For example, if the supported api-version of resource provider is 2020-01-01-preview and 2019-01-01: when passing in this parameter it will take the latest version 2020-01-01-preview, otherwise it will take the latest stable version 2019-01-01 without passing in this parameter
    - name -- The resource name. (Ex: myC)
    - namespace -- Provider namespace (Ex: 'Microsoft.Provider')
    - parent -- The parent path (Ex: 'resA/myA/resB/myB')
    - request_body -- JSON encoded parameter arguments for the action that will be passed along in the post request body. Use @{file} to load from a file.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type (Ex: 'resC'). Can also accept namespace/type format (Ex: 'Microsoft.Provider/resC')
    '''
    return _call_az("az resource invoke-action", locals())


def update(add=None, api_version=None, force_string=None, ids=None, include_response_body=None, latest_include_preview=None, name=None, namespace=None, parent=None, remove=None, resource_group=None, resource_type=None, set=None):
    '''
    Update a resource.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - api_version -- The api version of the resource (omit for the latest stable version)
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - ids -- One or more resource IDs (space-delimited). If provided, no other "Resource Id" arguments should be specified.
    - include_response_body -- Use if the default command output doesn't capture all of the property data.
    - latest_include_preview -- Indicate that the latest api-version will be used regardless of whether it is preview version (like 2020-01-01-preview) or not. For example, if the supported api-version of resource provider is 2020-01-01-preview and 2019-01-01: when passing in this parameter it will take the latest version 2020-01-01-preview, otherwise it will take the latest stable version 2019-01-01 without passing in this parameter
    - name -- The resource name. (Ex: myC)
    - namespace -- Provider namespace (Ex: 'Microsoft.Provider')
    - parent -- The parent path (Ex: 'resA/myA/resB/myB')
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type (Ex: 'resC'). Can also accept namespace/type format (Ex: 'Microsoft.Provider/resC')
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az resource update", locals())


def wait(api_version=None, created=None, custom=None, deleted=None, exists=None, ids=None, include_response_body=None, interval=None, name=None, namespace=None, parent=None, resource_group=None, resource_type=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a resources is met.

    Optional Parameters:
    - api_version -- The api version of the resource (omit for the latest stable version)
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - ids -- One or more resource IDs (space-delimited). If provided, no other "Resource Id" arguments should be specified.
    - include_response_body -- Use if the default command output doesn't capture all of the property data.
    - interval -- polling interval in seconds
    - name -- The resource name. (Ex: myC)
    - namespace -- Provider namespace (Ex: 'Microsoft.Provider')
    - parent -- The parent path (Ex: 'resA/myA/resB/myB')
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type (Ex: 'resC'). Can also accept namespace/type format (Ex: 'Microsoft.Provider/resC')
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az resource wait", locals())




'''
Manage Azure EventHubs Cluster for namespace
'''
from .... pyaz_utils import _call_az

def list(name, resource_group):
    '''
    List of Namespaces within given Cluster.

    Required Parameters:
    - name -- Name of Cluster
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs cluster namespace list", locals())




'''
Manage Azure NetApp Files (ANF) Pool Resources.
'''
from ... pyaz_utils import _call_az

def show(account_name, pool_name, resource_group):
    '''
    Get the specified ANF pool.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles pool show", locals())


def list(account_name, resource_group):
    '''
    L:ist the ANF pools for the specified account.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles pool list", locals())


def delete(account_name, pool_name, resource_group):
    '''
    Delete the specified ANF pool.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles pool delete", locals())


def create(account_name, location, pool_name, resource_group, service_level, size, cool_access=None, encryption_type=None, qos_type=None, tags=None):
    '''
    Create a new Azure NetApp Files (ANF) pool.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_level -- Service level
    - size -- Required. Provisioned size of the pool (in bytes). Allowed values are in 4TiB chunks (value must be multiply of 4398046511104).

    Optional Parameters:
    - cool_access -- If enabled (true) the pool can contain cool Access enabled volumes.
    - encryption_type -- Encryption type of the capacity pool, set encryption type for data at rest for this pool and all volumes in it. This value can only be set when creating new pool. Possible values include: "Single", "Double". Default value: "Single".
    - qos_type -- The qos type of the pool. Possible values include: "Auto", "Manual".
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az netappfiles pool create", locals())


def update(account_name, pool_name, resource_group, add=None, force_string=None, qos_type=None, remove=None, set=None, size=None, tags=None):
    '''
    Update the tags of the specified ANF pool.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - qos_type -- The qos type of the pool. Possible values include: "Auto", "Manual".
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - size -- Provisioned size of the pool (in bytes). Allowed values are in 4TiB chunks (value must be multiply of 4398046511104).
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az netappfiles pool update", locals())




from .... pyaz_utils import _call_az

def set(managed_instance, name, resource_group, retention_days, deleted_time=None, no_wait=None):
    '''
    Update short term retention for automated backups on a single database.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the Azure SQL Managed Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - retention_days -- New backup short term retention policy in days.Valid policy for live database is 7-35 days, valid policy for dropped databases is 0-35 days.

    Optional Parameters:
    - deleted_time -- If specified, updates retention days for a deleted database, instead of an existing database.Must match the deleted time of a deleted database on the source Managed Instance.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az sql midb short-term-retention-policy set", locals())


def show(managed_instance, name, resource_group, deleted_time=None):
    '''
    Show short term retention for automated backups on a single database.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the Azure SQL Managed Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - deleted_time -- If specified, shows retention days for a deleted database, instead of an existing database.Must match the deleted time of a deleted database on the source Managed Instance.
    '''
    return _call_az("az sql midb short-term-retention-policy show", locals())




from ... pyaz_utils import _call_az

def delete(gallery_image_definition, gallery_image_version, gallery_name, resource_group):
    '''
    

    Required Parameters:
    - gallery_image_definition -- gallery image definition
    - gallery_image_version -- Gallery image version in semantic version pattern. The allowed characters are digit and period. Digits must be within the range of a 32-bit integer, e.g. `<MajorVersion>.<MinorVersion>.<Patch>`
    - gallery_name -- gallery name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sig image-version delete", locals())


def show(gallery_image_definition, gallery_image_version, gallery_name, resource_group, expand=None):
    '''
    

    Required Parameters:
    - gallery_image_definition -- gallery image definition
    - gallery_image_version -- Gallery image version in semantic version pattern. The allowed characters are digit and period. Digits must be within the range of a 32-bit integer, e.g. `<MajorVersion>.<MinorVersion>.<Patch>`
    - gallery_name -- gallery name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- The expand expression to apply on the operation, e.g. 'ReplicationStatus'
    '''
    return _call_az("az sig image-version show", locals())


def list(gallery_image_definition, gallery_name, resource_group):
    '''
    

    Required Parameters:
    - gallery_image_definition -- gallery image definition
    - gallery_name -- gallery name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sig image-version list", locals())


def create(gallery_image_definition, gallery_image_version, gallery_name, resource_group, data_snapshot_luns=None, data_snapshots=None, data_vhds_luns=None, data_vhds_storage_accounts=None, data_vhds_uris=None, end_of_life_date=None, exclude_from_latest=None, location=None, managed_image=None, no_wait=None, os_snapshot=None, os_vhd_storage_account=None, os_vhd_uri=None, replica_count=None, replication_mode=None, storage_account_type=None, tags=None, target_region_encryption=None, target_regions=None):
    '''
    create a new image version

    Required Parameters:
    - gallery_image_definition -- gallery image definition
    - gallery_image_version -- Gallery image version in semantic version pattern. The allowed characters are digit and period. Digits must be within the range of a 32-bit integer, e.g. `<MajorVersion>.<MinorVersion>.<Patch>`
    - gallery_name -- gallery name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - data_snapshot_luns -- Logical unit numbers (space-delimited) of data disk snapshots
    - data_snapshots -- Names or IDs (space-delimited) of data disk snapshots
    - data_vhds_luns -- Logical unit numbers (space-delimited) of source VHD URIs of data disks
    - data_vhds_storage_accounts -- Names or IDs (space-delimited) of storage accounts of source VHD URIs of data disks
    - data_vhds_uris -- Source VHD URIs (space-delimited) of data disks
    - end_of_life_date -- the end of life date, e.g. '2020-12-31'
    - exclude_from_latest -- The flag means that if it is set to true, people deploying VMs with version omitted will not use this version.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - managed_image -- image name(if in the same resource group) or resource id
    - no_wait -- Do not wait for the long-running operation to finish.
    - os_snapshot -- Name or ID of OS disk snapshot
    - os_vhd_storage_account -- Name or ID of storage account of source VHD URI of OS disk
    - os_vhd_uri -- Source VHD URI of OS disk
    - replica_count -- The default number of replicas to be created per region. To set regional replication counts, use --target-regions
    - replication_mode -- Optional parameter which specifies the mode to be used for replication. This property is not updatable.
    - storage_account_type -- The default storage account type to be used per region. To set regional storage account types, use --target-regions
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - target_region_encryption -- Space-separated list of customer managed keys for encrypting the OS and data disks in the gallery artifact for each region. Format for each region: `<os_des>,<lun1>,<lun1_des>,<lun2>,<lun2_des>`. Use "null" as a placeholder.
    - target_regions -- Space-separated list of regions and their replica counts. Use `<region>[=<replica count>][=<storage account type>]` to optionally set the replica count and/or storage account type for each region. If a replica count is not specified, the default replica count will be used. If a storage account type is not specified, the default storage account type will be used
    '''
    return _call_az("az sig image-version create", locals())


def update(gallery_image_definition, gallery_image_version, gallery_name, resource_group, add=None, force_string=None, no_wait=None, remove=None, replica_count=None, set=None, target_regions=None):
    '''
    update a share image version

    Required Parameters:
    - gallery_image_definition -- gallery image definition
    - gallery_image_version -- Gallery image version in semantic version pattern. The allowed characters are digit and period. Digits must be within the range of a 32-bit integer, e.g. `<MajorVersion>.<MinorVersion>.<Patch>`
    - gallery_name -- gallery name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - replica_count -- The default number of replicas to be created per region. To set regional replication counts, use --target-regions
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - target_regions -- Space-separated list of regions and their replica counts. Use `<region>[=<replica count>][=<storage account type>]` to optionally set the replica count and/or storage account type for each region. If a replica count is not specified, the default replica count will be used. If a storage account type is not specified, the default storage account type will be used
    '''
    return _call_az("az sig image-version update", locals())


def wait(gallery_image_definition, gallery_image_version, gallery_name, resource_group, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    wait for image version related operation

    Required Parameters:
    - gallery_image_definition -- gallery image definition
    - gallery_image_version -- Gallery image version in semantic version pattern. The allowed characters are digit and period. Digits must be within the range of a 32-bit integer, e.g. `<MajorVersion>.<MinorVersion>.<Patch>`
    - gallery_name -- gallery name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - expand -- The expand expression to apply on the operation.
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az sig image-version wait", locals())


def list_shared(gallery_image_definition, gallery_unique_name, location, shared_to=None):
    '''
    List VM Image Versions in a gallery shared directly to your subscription or tenant (preview).

    Required Parameters:
    - gallery_image_definition -- The name of the Shared Gallery Image Definition from which the Image Versions are to be listed.
    - gallery_unique_name -- The unique name of the Shared Gallery.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.

    Optional Parameters:
    - shared_to -- The query parameter to decide what shared galleries to fetch when doing listing operations. If not specified, list by subscription id.
    '''
    return _call_az("az sig image-version list-shared", locals())


def show_shared(gallery_image_definition, gallery_image_version, gallery_unique_name, location):
    '''
    Get an image version in a gallery shared directly to your subscription or tenant (preview).

    Required Parameters:
    - gallery_image_definition -- The name of the Shared Gallery Image Definition from which the Image Versions are to be listed.
    - gallery_image_version -- The name of the gallery image version to be created. Needs to follow semantic version name pattern: The allowed characters are digit and period. Digits must be within the range of a 32-bit integer. Format: <MajorVersion>.<MinorVersion>.<Patch>
    - gallery_unique_name -- The unique name of the Shared Gallery.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az sig image-version show-shared", locals())




'''
Manage kusto pool with synapse
'''
from .... pyaz_utils import _call_az

def list_sku(name, resource_group, workspace_name):
    '''
    Returns the SKUs available for the provided resource.

    Required Parameters:
    - name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace
    '''
    return _call_az("az synapse kusto pool list-sku", locals())


def list(resource_group, workspace_name):
    '''
    List all Kusto pools.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace
    '''
    return _call_az("az synapse kusto pool list", locals())


def show(name, resource_group, workspace_name):
    '''
    Gets a Kusto pool.

    Required Parameters:
    - name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace
    '''
    return _call_az("az synapse kusto pool show", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Deletes a Kusto pool.

    Required Parameters:
    - name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse kusto pool delete", locals())


def list_follower_database(name, resource_group, workspace_name):
    '''
    Returns a list of databases that are owned by this Kusto Pool and were followed by another Kusto Pool.

    Required Parameters:
    - name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace
    '''
    return _call_az("az synapse kusto pool list-follower-database", locals())


def list_language_extension(name, resource_group, workspace_name):
    '''
    Returns a list of language extensions that can run within KQL queries.

    Required Parameters:
    - name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace
    '''
    return _call_az("az synapse kusto pool list-language-extension", locals())


def start(name, resource_group, workspace_name, no_wait=None):
    '''
    Starts a Kusto pool.

    Required Parameters:
    - name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse kusto pool start", locals())


def stop(name, resource_group, workspace_name, no_wait=None):
    '''
    Stops a Kusto pool.

    Required Parameters:
    - name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse kusto pool stop", locals())


def wait(name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the synapse kusto pool is met.

    Required Parameters:
    - name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse kusto pool wait", locals())


def create(name, resource_group, sku, workspace_name, enable_purge=None, enable_streaming_ingest=None, if_match=None, if_none_match=None, location=None, no_wait=None, optimized_autoscale=None, tags=None, workspace_uid=None):
    '''
    Create a Kusto pool.

    Required Parameters:
    - name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku -- The SKU of the kusto pool.
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - enable_purge -- A boolean value that indicates if the purge operations are enabled.
    - enable_streaming_ingest -- A boolean value that indicates if the streaming ingest is enabled.
    - if_match -- The ETag of the Kusto Pool. Omit this value to always overwrite the current Kusto Pool. Specify the last-seen ETag value to prevent accidentally overwriting concurrent changes.
    - if_none_match -- Set to '*' to allow a new Kusto Pool to be created, but to prevent updating an existing Kusto Pool. Other values will result in a 412 Pre-condition Failed response.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - optimized_autoscale -- Optimized auto scale definition.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - workspace_uid -- The workspace unique identifier.
    '''
    return _call_az("az synapse kusto pool create", locals())


def update(name, resource_group, workspace_name, enable_purge=None, enable_streaming_ingest=None, if_match=None, no_wait=None, optimized_autoscale=None, sku=None, tags=None, workspace_uid=None):
    '''
    Update a Kusto Kusto Pool.

    Required Parameters:
    - name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - enable_purge -- A boolean value that indicates if the purge operations are enabled.
    - enable_streaming_ingest -- A boolean value that indicates if the streaming ingest is enabled.
    - if_match -- The ETag of the Kusto Pool. Omit this value to always overwrite the current Kusto Pool. Specify the last-seen ETag value to prevent accidentally overwriting concurrent changes.
    - no_wait -- Do not wait for the long-running operation to finish.
    - optimized_autoscale -- Optimized auto scale definition.
    - sku -- The SKU of the kusto pool.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - workspace_uid -- The workspace unique identifier.
    '''
    return _call_az("az synapse kusto pool update", locals())


def add_language_extension(name, resource_group, workspace_name, no_wait=None, value=None):
    '''
    Add a list of language extensions that can run within KQL queries.

    Required Parameters:
    - name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - value -- The list of language extensions.
    '''
    return _call_az("az synapse kusto pool add-language-extension", locals())


def detach_follower_database(attached_database_configuration_name, kusto_pool_resource_id, name, resource_group, workspace_name, no_wait=None):
    '''
    Detaches all followers of a database owned by this Kusto Pool.

    Required Parameters:
    - attached_database_configuration_name -- Resource name of the attached database configuration in the follower cluster.
    - kusto_pool_resource_id -- Resource id of the cluster that follows a database owned by this cluster.
    - name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse kusto pool detach-follower-database", locals())


def remove_language_extension(name, resource_group, workspace_name, no_wait=None, value=None):
    '''
    Remove a list of language extensions that can run within KQL queries.

    Required Parameters:
    - name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - value -- The list of language extensions.
    '''
    return _call_az("az synapse kusto pool remove-language-extension", locals())




'''
Manage backups for web apps.
'''
from .... pyaz_utils import _call_az

def list(resource_group, webapp_name, slot=None):
    '''
    List backups of a web app.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - webapp_name -- The name of the web app

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config backup list", locals())


def show(resource_group, webapp_name, slot=None):
    '''
    Show the backup schedule for a web app.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - webapp_name -- The name of the web app

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config backup show", locals())


def create(container_url, resource_group, webapp_name, backup_name=None, db_connection_string=None, db_name=None, db_type=None, slot=None):
    '''
    Create a backup of a web app.

    Required Parameters:
    - container_url -- URL with SAS token to the blob storage container
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - webapp_name -- The name of the web app

    Optional Parameters:
    - backup_name -- Name of the backup. If unspecified, the backup will be named with the web app name and a timestamp
    - db_connection_string -- Connection string for the database in the backup
    - db_name -- Name of the database in the backup
    - db_type -- Type of database in the backup
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config backup create", locals())


def update(resource_group, webapp_name, backup_name=None, container_url=None, db_connection_string=None, db_name=None, db_type=None, frequency=None, retain_one=None, retention=None, slot=None):
    '''
    Configure a new backup schedule for a web app.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - webapp_name -- The name of the web app

    Optional Parameters:
    - backup_name -- Name of the backup. If unspecified, the backup will be named with the web app name and a timestamp
    - container_url -- URL with SAS token to the blob storage container
    - db_connection_string -- Connection string for the database in the backup
    - db_name -- Name of the database in the backup
    - db_type -- Type of database in the backup
    - frequency -- How often to backup. Use a number followed by d or h, e.g. 5d = 5 days, 2h = 2 hours
    - retain_one -- Always keep one backup, regardless of how old it is
    - retention -- How many days to keep a backup before automatically deleting it. Set to 0 for indefinite retention
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config backup update", locals())


def restore(backup_name, container_url, resource_group, webapp_name, db_connection_string=None, db_name=None, db_type=None, ignore_hostname_conflict=None, overwrite=None, slot=None, target_name=None):
    '''
    Restore a web app from a backup.

    Required Parameters:
    - backup_name -- Name of the backup to restore
    - container_url -- URL with SAS token to the blob storage container
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - webapp_name -- The name of the web app

    Optional Parameters:
    - db_connection_string -- Connection string for the database in the backup
    - db_name -- Name of the database in the backup
    - db_type -- Type of database in the backup
    - ignore_hostname_conflict -- Ignores custom hostnames stored in the backup
    - overwrite -- Overwrite the source web app, if --target-name is not specified
    - slot -- the name of the slot. Default to the productions slot if not specified
    - target_name -- The name to use for the restored web app. If unspecified, will default to the name that was used when the backup was created
    '''
    return _call_az("az webapp config backup restore", locals())




'''
Manage secrets within the specified profile.
'''
from ... pyaz_utils import _call_az

def show(profile_name, resource_group, secret_name):
    '''
    

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - secret_name -- Name of the secret.
    '''
    return _call_az("az afd secret show", locals())


def delete(profile_name, resource_group, secret_name, yes=None):
    '''
    

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - secret_name -- Name of the secret.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az afd secret delete", locals())


def list(profile_name, resource_group):
    '''
    

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd secret list", locals())


def create(profile_name, resource_group, secret_name, secret_source, secret_version=None, use_latest_version=None):
    '''
    Creates a new secret within the specified profile.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - secret_name -- Name of the secret.
    - secret_source -- ID of the Azure key vault certificate.

    Optional Parameters:
    - secret_version -- Version of the certificate to be used.
    - use_latest_version -- Whether to use the latest version for the certificate.
    '''
    return _call_az("az afd secret create", locals())


def update(profile_name, resource_group, secret_name, secret_source=None, secret_version=None, use_latest_version=None):
    '''
    Update an existing secret within the specified profile.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - secret_name -- Name of the secret.

    Optional Parameters:
    - secret_source -- ID of the Azure key vault certificate.
    - secret_version -- Version of the certificate to be used.
    - use_latest_version -- Whether to use the latest version for the certificate.
    '''
    return _call_az("az afd secret update", locals())




from ... pyaz_utils import _call_az

def convert(name, resource_group):
    '''
    Convert an Azure Availability Set to contain VMs with managed disks.

    Required Parameters:
    - name -- Name of the availability set
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm availability-set convert", locals())


def create(name, resource_group, location=None, no_wait=None, platform_fault_domain_count=None, platform_update_domain_count=None, ppg=None, tags=None, unmanaged=None, validate=None):
    '''
    Create an Azure Availability Set.

    Required Parameters:
    - name -- Name of the availability set
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - platform_fault_domain_count -- Fault Domain count.
    - platform_update_domain_count -- Update Domain count. If unspecified, the server will pick the most optimal number like 5.
    - ppg -- The name or ID of the proximity placement group the availability set should be associated with.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - unmanaged -- contained VMs should use unmanaged disks
    - validate -- Generate and validate the ARM template without creating any resources.
    '''
    return _call_az("az vm availability-set create", locals())


def delete(name, resource_group):
    '''
    Delete an availability set.

    Required Parameters:
    - name -- Name of the availability set
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm availability-set delete", locals())


def list(resource_group=None):
    '''
    List availability sets.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm availability-set list", locals())


def list_sizes(name, resource_group):
    '''
    List VM sizes for an availability set.

    Required Parameters:
    - name -- Name of the availability set
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm availability-set list-sizes", locals())


def show(name, resource_group):
    '''
    Get information for an availability set.

    Required Parameters:
    - name -- Name of the availability set
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm availability-set show", locals())


def update(name, resource_group, add=None, force_string=None, ppg=None, remove=None, set=None):
    '''
    Update an Azure Availability Set.

    Required Parameters:
    - name -- Name of the availability set
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - ppg -- The name or ID of the proximity placement group the availability set should be associated with.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az vm availability-set update", locals())




'''
Manage shared access policies of an IoT hub.
'''
from .... pyaz_utils import _call_az

def list(hub_name, resource_group=None):
    '''
    List shared access policies of an IoT hub.

    Required Parameters:
    - hub_name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub policy list", locals())


def show(hub_name, name, resource_group=None):
    '''
    Get the details of a shared access policy of an IoT hub.

    Required Parameters:
    - hub_name -- IoT Hub name.
    - name -- Shared access policy name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub policy show", locals())


def create(hub_name, name, permissions, resource_group=None):
    '''
    Create a new shared access policy in an IoT hub.

    Required Parameters:
    - hub_name -- IoT Hub name.
    - name -- Shared access policy name.
    - permissions -- Permissions of shared access policy. Use space-separated list for multiple permissions. Possible values: RegistryRead, RegistryWrite, ServiceConnect, DeviceConnect

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub policy create", locals())


def delete(hub_name, name, resource_group=None):
    '''
    Delete a shared access policy from an IoT hub.

    Required Parameters:
    - hub_name -- IoT Hub name.
    - name -- Shared access policy name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub policy delete", locals())


def renew_key(hub_name, name, renew_key, no_wait=None, resource_group=None):
    '''
    Regenerate keys of a shared access policy of an IoT hub.

    Required Parameters:
    - hub_name -- IoT Hub name.
    - name -- Shared access policy name.
    - renew_key -- Regenerate keys

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub policy renew-key", locals())




'''
Manage formulas for an Azure DevTest Lab.
'''
from ... pyaz_utils import _call_az

def show(lab_name, name, resource_group, expand=None):
    '''
    Show formulae from an Azure DevTest Lab.

    Required Parameters:
    - lab_name -- The name of the lab.
    - name -- The name of the formula.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Specify the $expand query. Example: 'properties($select=description)'
    '''
    return _call_az("az lab formula show", locals())


def list(lab_name, resource_group, expand=None, filter=None, orderby=None, top=None):
    '''
    

    Required Parameters:
    - lab_name -- The name of the lab.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Specify the $expand query. Example: 'properties($select=description)'
    - filter -- The filter to apply to the operation. Example: '$filter=contains(name,'myName')
    - orderby -- The ordering expression for the results, using OData notation. Example: '$orderby=name desc'
    - top -- The maximum number of resources to return from the operation. Example: '$top=10'
    '''
    return _call_az("az lab formula list", locals())


def delete(lab_name, name, resource_group):
    '''
    

    Required Parameters:
    - lab_name -- The name of the lab.
    - name -- The name of the formula.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az lab formula delete", locals())


def export_artifacts(lab_name, name, resource_group):
    '''
    Export artifacts from a formula.

    Required Parameters:
    - lab_name -- The name of the lab.
    - name -- The name of the formula.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az lab formula export-artifacts", locals())




from .... pyaz_utils import _call_az

def set(diffbackup_hours, name, resource_group, retention_days, server, no_wait=None):
    '''
    Update short term retention settings for a live database.

    Required Parameters:
    - diffbackup_hours -- New backup short term retention policy differential backup interval in hours.Valid differential backup interval for live database can be 12 or 24 hours.
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - retention_days -- New backup short term retention policy retention in days.Valid retention days for live database of (DTU) Basic can be 1-7 days; Rest models can be 1-35 days.
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az sql db str-policy set", locals())


def show(name, resource_group, server):
    '''
    Show the short term retention policy for a live database.

    Required Parameters:
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql db str-policy show", locals())


def wait(name, policy_name, resource_group, server, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until the policy is set.

    Required Parameters:
    - name -- Name of the Azure SQL Database.
    - policy_name -- The policy name. Should always be "default".
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az sql db str-policy wait", locals())




'''
Manage Azure Cosmos DB Cassandra tables.
'''
from .... pyaz_utils import _call_az
from . import throughput


def create(account_name, keyspace_name, name, resource_group, schema, analytical_storage_ttl=None, max_throughput=None, throughput=None, ttl=None):
    '''
    Create an Cassandra table under an Azure Cosmos DB Cassandra keyspace.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - keyspace_name -- Keyspace name
    - name -- Table name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schema -- Schema, you can enter it as a string or as a file, e.g., --schema @schema-file.json or --schema "{\"columns\": [{\"name\": \"columnA\",\"type\": \"uuid\"}, {\"name\": \"columnB\",\"type\": \"Ascii\"}],\"partitionKeys\": [{\"name\": \"columnA\"}]}"


    Optional Parameters:
    - analytical_storage_ttl -- Analytical TTL, when analytical storage is enabled.
    - max_throughput -- The maximum throughput resource can scale to (RU/s). Provided when the resource is autoscale enabled. The minimum value can be 4000 (RU/s)
    - throughput -- The throughput of Cassandra table (RU/s). Default value is 400. Omit this parameter if the keyspace has shared throughput unless the table should have dedicated throughput.
    - ttl -- Default TTL. If the value is missing or set to "-1", items don’t expire. If the value is set to "n", items will expire "n" seconds after last modified time.
    '''
    return _call_az("az cosmosdb cassandra table create", locals())


def update(account_name, keyspace_name, name, resource_group, analytical_storage_ttl=None, schema=None, ttl=None):
    '''
    Update an Cassandra table under an Azure Cosmos DB Cassandra keyspace.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - keyspace_name -- Keyspace name
    - name -- Table name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - analytical_storage_ttl -- Analytical TTL, when analytical storage is enabled.
    - schema -- Schema, you can enter it as a string or as a file, e.g., --schema @schema-file.json or --schema "{\"columns\": [{\"name\": \"columnA\",\"type\": \"uuid\"}, {\"name\": \"columnB\",\"type\": \"Ascii\"}],\"partitionKeys\": [{\"name\": \"columnA\"}]}"

    - ttl -- Default TTL. If the value is missing or set to "-1", items don’t expire. If the value is set to "n", items will expire "n" seconds after last modified time.
    '''
    return _call_az("az cosmosdb cassandra table update", locals())


def exists(account_name, keyspace_name, name, resource_group):
    '''
    

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - keyspace_name -- Keyspace name
    - name -- Table name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb cassandra table exists", locals())


def list(account_name, keyspace_name, resource_group):
    '''
    List the Cassandra tables under an Azure Cosmos DB Cassandra keyspace.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - keyspace_name -- Keyspace name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb cassandra table list", locals())


def show(account_name, keyspace_name, name, resource_group):
    '''
    Show the details of a Cassandra table under an Azure Cosmos DB Cassandra keyspace.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - keyspace_name -- Keyspace name
    - name -- Table name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb cassandra table show", locals())


def delete(account_name, keyspace_name, name, resource_group, yes=None):
    '''
    Delete the Cassandra table under an Azure Cosmos DB Cassandra keyspace.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - keyspace_name -- Keyspace name
    - name -- Table name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cosmosdb cassandra table delete", locals())




from .... pyaz_utils import _call_az

def update(name, registry, add=None, remove=None, resource_group=None):
    '''
    Add and remove repository permissions accross all the necessary connected registry sync scope maps.

    Required Parameters:
    - name -- Name for the connected registry. Name must be between 5 to 40 character long, start with a letter and contain only alphanumeric characters (including ‘_’ or ‘-’). Name must be unique under the Cloud ACR hierarchy.
    - registry -- The login server of the Cloud ACR registry. Must be the FQDN to support also Azure Stack.

    Optional Parameters:
    - add -- repository permissions to be added to the targeted connected registry and it's ancestors sync scope maps. Use the format "--add [REPO1 REPO2 ...]" per flag. Valid actions are {'content/read', 'content/write', 'metadata/write', 'metadata/read', 'content/delete'}
    - remove -- respsitory permissions to be removed from the targeted connected registry and it's succesors sync scope maps. Use the format "--remove [REPO1 REPO2 ...]" per flag. Valid actions are {'content/read', 'content/write', 'metadata/write', 'metadata/read', 'content/delete'}
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr connected-registry permissions update", locals())


def show(name, registry, resource_group=None):
    '''
    Show the connected registry sync scope map information.

    Required Parameters:
    - name -- Name for the connected registry. Name must be between 5 to 40 character long, start with a letter and contain only alphanumeric characters (including ‘_’ or ‘-’). Name must be unique under the Cloud ACR hierarchy.
    - registry -- The login server of the Cloud ACR registry. Must be the FQDN to support also Azure Stack.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr connected-registry permissions show", locals())




from ...... pyaz_utils import _call_az

def set(name, policy_name, resource_group, rule_set_type, rule_set_version):
    '''
    Add or update a rule group override to a managed rule set on a CDN WAF policy.

    Required Parameters:
    - name -- The name of the rule group.
    - policy_name -- Name of the CDN WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_type -- The type of the managed rule set.
    - rule_set_version -- The version of the managed rule set.
    '''
    return _call_az("az cdn waf policy managed-rule-set rule-group-override set", locals())


def delete(name, policy_name, resource_group, rule_set_type, rule_set_version, yes=None):
    '''
    Remove a rule group override from a managed rule set on a CDN WAF policy.

    Required Parameters:
    - name -- The name of the rule group.
    - policy_name -- Name of the CDN WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_type -- The type of the managed rule set.
    - rule_set_version -- The version of the managed rule set.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cdn waf policy managed-rule-set rule-group-override delete", locals())


def list(policy_name, resource_group, rule_set_type, rule_set_version):
    '''
    List rule group overrides of a managed rule on a CDN WAF policy.

    Required Parameters:
    - policy_name -- Name of the CDN WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_type -- The type of the managed rule set.
    - rule_set_version -- The version of the managed rule set.
    '''
    return _call_az("az cdn waf policy managed-rule-set rule-group-override list", locals())


def show(name, policy_name, resource_group, rule_set_type, rule_set_version):
    '''
    Show a rule group override of a managed rule on a CDN WAF policy.

    Required Parameters:
    - name -- The name of the rule group.
    - policy_name -- Name of the CDN WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_type -- The type of the managed rule set.
    - rule_set_version -- The version of the managed rule set.
    '''
    return _call_az("az cdn waf policy managed-rule-set rule-group-override show", locals())


def list_available(rule_set_type, rule_set_version):
    '''
    List available CDN WAF managed rule groups of a managed rule set.

    Required Parameters:
    - rule_set_type -- The type of the managed rule set.
    - rule_set_version -- The version of the managed rule set.
    '''
    return _call_az("az cdn waf policy managed-rule-set rule-group-override list-available", locals())




'''
Manage near-realtime metric alert rule conditions.
'''
from ..... pyaz_utils import _call_az

def create(aggregation, metric, operator, type, dimension=None, namespace=None, num_periods=None, num_violations=None, sensitivity=None, since=None, skip_metric_validation=None, threshold=None):
    '''
    Build a metric alert rule condition.

    Required Parameters:
    - aggregation -- Time aggregation.
    - metric -- Name of metric.
    - operator -- Operator for static threshold can be 'Equals', 'NotEquals', 'GreaterThan', 'GreaterThanOrEqual', 'LessThan' or 'LessThanOrEqual'. Operator for dynamic threshold can be 'GreaterThan', 'LessThan', 'GreaterOrLessThan'.
    - type -- Type of condition threshold.

    Optional Parameters:
    - dimension -- Dimension created by 'az monitor metrics alert dimension create'.
    - namespace -- Namespace of metric.
    - num_periods -- The number of evaluation periods for dynamic threshold. Range: 1-6.
    - num_violations -- The number of violations to trigger an dynamic alert. Range: 1-6. It should be less than or equal to --num-periods.
    - sensitivity -- Alert sensitivity for dynamic threshold.
    - since -- The date from which to start learning the metric historical data and calculate the dynamic thresholds. Format: date (yyyy-mm-dd) time (hh:mm:ss.xxxxx) timezone (+/-hh:mm)
    - skip_metric_validation -- Cause the metric validation to be skipped. This allows to use a metric that has not been emitted yet.
    - threshold -- Static threshold value.
    '''
    return _call_az("az monitor metrics alert condition create", locals())




from .... pyaz_utils import _call_az

def show(account_endpoint=None, account_key=None, account_name=None):
    '''
    Get lifetime summary statistics for all of the pools in a Batch account.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    '''
    return _call_az("az batch pool all-statistics show", locals())




from .... pyaz_utils import _call_az

def show(hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Get the rotation policy of a Key Vault key.

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Id of the key. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the key. Required if --id is not specified.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key rotation-policy show", locals())


def update(value, hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Update the rotation policy of a Key Vault key.

    Required Parameters:
    - value -- The rotation policy file definition as JSON, or a path to a file containing JSON policy definition.

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Id of the key. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the key. Required if --id is not specified.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key rotation-policy update", locals())




'''
Manage Azure Event Grid topics, domains, domain topics, system topics partner topics, event subscriptions, system topic event subscriptions and partner topic event subscriptions.
'''
from .. pyaz_utils import _call_az
from . import event_subscription, extension_topic, system_topic, topic, topic_type




'''
Manage Data Lake Analytics accounts.
'''
from ... pyaz_utils import _call_az
from . import blob_storage, compute_policy, data_lake_store, firewall


def create(account, default_data_lake_store, location=None, max_degree_of_parallelism=None, max_job_count=None, query_store_retention=None, resource_group=None, tags=None, tier=None):
    '''
    Create a Data Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - default_data_lake_store -- None

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - max_degree_of_parallelism -- None
    - max_job_count -- None
    - query_store_retention -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tier -- The desired commitment tier for this account to use.
    '''
    return _call_az("az dla account create", locals())


def update(account, allow_azure_ips=None, firewall_state=None, max_degree_of_parallelism=None, max_job_count=None, query_store_retention=None, resource_group=None, tags=None, tier=None):
    '''
    Update a Data Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.

    Optional Parameters:
    - allow_azure_ips -- Allow/block Azure originating IPs through the firewall
    - firewall_state -- Enable/disable existing firewall rules.
    - max_degree_of_parallelism -- The maximum supported degree of parallelism for this account.
    - max_job_count -- The maximum supported jobs running under the account at the same time.
    - query_store_retention -- The number of days that job metadata is retained.
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Analytics account.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tier -- The desired commitment tier for this account to use.
    '''
    return _call_az("az dla account update", locals())


def list(resource_group=None):
    '''
    List available Data Lake Analytics accounts.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az dla account list", locals())


def show(account, resource_group=None):
    '''
    Get the details of a Data Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Analytics account.
    '''
    return _call_az("az dla account show", locals())


def delete(account, resource_group=None):
    '''
    Delete a Data Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Analytics account.
    '''
    return _call_az("az dla account delete", locals())




'''
Manage deployments for Azure Cognitive Services accounts.
'''
from .... pyaz_utils import _call_az

def create(model_format, model_name, model_version, name, resource_group, scale_capacity, scale_type, deployment_name=None):
    '''
    Create a deployment for Azure Cognitive Services account.

    Required Parameters:
    - model_format -- Cognitive Services account deployment model format.
    - model_name -- Cognitive Services account deployment model name.
    - model_version -- Cognitive Services account deployment model version.
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scale_capacity -- Cognitive Services account deployment scale settings capacity.
    - scale_type -- Cognitive Services account deployment scale settings scale type.

    Optional Parameters:
    - deployment_name -- Cognitive Services account deployment name
    '''
    return _call_az("az cognitiveservices account deployment create", locals())


def delete(name, resource_group, deployment_name=None):
    '''
    Delete a deployment from Azure Cognitive Services account.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - deployment_name -- Cognitive Services account deployment name
    '''
    return _call_az("az cognitiveservices account deployment delete", locals())


def show(name, resource_group, deployment_name=None):
    '''
    Show a deployment for Azure Cognitive Services account.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - deployment_name -- Cognitive Services account deployment name
    '''
    return _call_az("az cognitiveservices account deployment show", locals())


def list(name, resource_group):
    '''
    Show all deployments for Azure Cognitive Services account.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account deployment list", locals())




'''
Encryption details of a Recovery Services Vault.
'''
from .... pyaz_utils import _call_az

def update(encryption_key_id, name, resource_group, infrastructure_encryption=None, mi_system_assigned=None, mi_user_assigned=None):
    '''
    Update encryption properties of a Recovery Services Vault.

    Required Parameters:
    - encryption_key_id -- The encryption key id you want to use for encryption
    - name -- Name of the Recovery services vault.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - infrastructure_encryption -- Use this parameter to enable/disable infrastructure encryption. This must be set when configuring encryption of the vault for the first time. Once enabled/disabled, infrastructure encryption setting cannot be changed. Default value: Disabled. Allowed values: Enabled, Disabled
    - mi_system_assigned -- Provide this flag to use system assigned identity for encryption.
    - mi_user_assigned -- UserAssigned Identity Id to be used for CMK encryption, this will be applicable for encryption using userassigned identity
    '''
    return _call_az("az backup vault encryption update", locals())


def show(name, resource_group):
    '''
    Show details of encryption properties of a Recovery Services Vault.

    Required Parameters:
    - name -- Name of the Recovery services vault.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az backup vault encryption show", locals())




from .... pyaz_utils import _call_az

def create(address_pool, frontend_ip_configs, lb_name, name, protocol, resource_group, enable_tcp_reset=None, idle_timeout=None, outbound_ports=None):
    '''
    Create an outbound-rule.

    Required Parameters:
    - address_pool -- Name or ID of the backend address pool.
    - frontend_ip_configs -- Space-separated list of frontend IP configuration names or IDs.
    - lb_name -- The load balancer name.
    - name -- The name of the outbound rule
    - protocol -- Network transport protocol.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - enable_tcp_reset -- Receive bidirectional TCP reset on TCP flow idle timeout or unexpected connection termination. Only used when protocol is set to TCP.
    - idle_timeout -- Idle timeout in minutes.
    - outbound_ports -- The number of outbound ports to be used for NAT.
    '''
    return _call_az("az network lb outbound-rule create", locals())


def update(lb_name, name, resource_group, add=None, address_pool=None, enable_tcp_reset=None, force_string=None, frontend_ip_configs=None, idle_timeout=None, outbound_ports=None, protocol=None, remove=None, set=None):
    '''
    Update an outbound-rule.

    Required Parameters:
    - lb_name -- The load balancer name.
    - name -- The name of the outbound rule
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - address_pool -- Name or ID of the backend address pool.
    - enable_tcp_reset -- Receive bidirectional TCP reset on TCP flow idle timeout or unexpected connection termination. Only used when protocol is set to TCP.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - frontend_ip_configs -- Space-separated list of frontend IP configuration names or IDs.
    - idle_timeout -- Idle timeout in minutes.
    - outbound_ports -- The number of outbound ports to be used for NAT.
    - protocol -- Network transport protocol.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network lb outbound-rule update", locals())


def list(lb_name, resource_group):
    '''
    List outbound rules.

    Required Parameters:
    - lb_name -- The name of the load balancer.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network lb outbound-rule list", locals())


def show(lb_name, name, resource_group):
    '''
    Get the details of an outbound rule.

    Required Parameters:
    - lb_name -- The name of the load balancer.
    - name -- The name of the outbound rule
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network lb outbound-rule show", locals())


def delete(lb_name, name, resource_group):
    '''
    Delete an outbound-rule.

    Required Parameters:
    - lb_name -- The name of the load balancer.
    - name -- The name of the outbound rule
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network lb outbound-rule delete", locals())




'''
billing product
'''
from ... pyaz_utils import _call_az

def list(account_name, customer_name=None, filter=None, invoice_section_name=None, profile_name=None):
    '''
    List the products for a billing account. These don't include products billed based on usage. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement or Microsoft Partner Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - customer_name -- The ID that uniquely identifies a customer.
    - filter -- May be used to filter by product type. The filter supports 'eq', 'lt', 'gt', 'le', 'ge', and 'and'. It does not currently support 'ne', 'or', or 'not'. Tag filter is a key value pair string where key and value are separated by a colon (:).
    - invoice_section_name -- The ID that uniquely identifies an invoice section.
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing product list", locals())


def show(account_name, name):
    '''
    Get a product by ID. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies a product.
    '''
    return _call_az("az billing product show", locals())


def update(account_name, name, auto_renew=None, billing_frequency=None, status=None):
    '''
    Update the properties of a Product. Currently, auto renew can be updated. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies a product.

    Optional Parameters:
    - auto_renew -- Indicates whether auto renewal is turned on or off for a product.
    - billing_frequency -- The frequency at which the product will be billed.
    - status -- The current status of the product.
    '''
    return _call_az("az billing product update", locals())


def move(account_name, name, destination_invoice_section_id=None):
    '''
    Moves a product's charges to a new invoice section. The new invoice section must belong to the same billing profile as the existing invoice section. This operation is supported only for products that are purchased with a recurring charge and for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies a product.

    Optional Parameters:
    - destination_invoice_section_id -- The destination invoice section id.
    '''
    return _call_az("az billing product move", locals())


def validate_move(account_name, name, destination_invoice_section_id=None):
    '''
    Validate if a product's charges can be moved to a new invoice section. This operation is supported only for products that are purchased with a recurring charge and for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies a product.

    Optional Parameters:
    - destination_invoice_section_id -- The destination invoice section id.
    '''
    return _call_az("az billing product validate-move", locals())




'''
Manage deployment operations at subscription scope.
'''
from .... pyaz_utils import _call_az

def list(name):
    '''
    List deployment operations at subscription scope.

    Required Parameters:
    - name -- The deployment name.
    '''
    return _call_az("az deployment operation sub list", locals())


def show(name, operation_ids):
    '''
    Show a deployment operation at subscription scope.

    Required Parameters:
    - name -- The deployment name.
    - operation_ids -- A list of operation ids to show
    '''
    return _call_az("az deployment operation sub show", locals())




'''
Apply a CDN WAF policy to a CDN endpoint.
'''
from ..... pyaz_utils import _call_az

def show(endpoint_name, profile_name, resource_group):
    '''
    Show which CDN WAF policy is applied to a CDN endpoint.

    Required Parameters:
    - endpoint_name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn endpoint waf policy show", locals())


def set(endpoint_name, profile_name, resource_group, waf_policy_id=None, waf_policy_name=None, waf_policy_resource_group_name=None, waf_policy_subscription_id=None):
    '''
    Set the CDN WAF policy applied to a CDN endpoint

    Required Parameters:
    - endpoint_name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - waf_policy_id -- None
    - waf_policy_name -- None
    - waf_policy_resource_group_name -- None
    - waf_policy_subscription_id -- None
    '''
    return _call_az("az cdn endpoint waf policy set", locals())


def remove(endpoint_name, profile_name, resource_group, yes=None):
    '''
    Remove a CDN WAF policy from a CDN endpoint.

    Required Parameters:
    - endpoint_name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cdn endpoint waf policy remove", locals())




from .... pyaz_utils import _call_az

def create(name, resource_group, sku_capacity, identity_type=None, location=None, no_wait=None, sku_name=None, tags=None):
    '''
    Create a cluster instance.

    Required Parameters:
    - name -- The name of the Log Analytics cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku_capacity -- The capacity of the SKU. It must be in the range of 1000-2000 per day and must be in multiples of 100. If you want to increase the limit, please contact LAIngestionRate@microsoft.com. It can be decreased only after 31 days.

    Optional Parameters:
    - identity_type -- The identity type. Supported values: SystemAssigned
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - sku_name -- The name of the SKU. Currently only support 'CapacityReservation'
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az monitor log-analytics cluster create", locals())


def update(name, resource_group, key_name=None, key_vault_uri=None, key_version=None, sku_capacity=None, tags=None):
    '''
    Update a cluster instance.

    Required Parameters:
    - name -- The name of the Log Analytics cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - key_name -- The name of the key associated with the Log Analytics cluster.
    - key_vault_uri -- The Key Vault uri which holds the key associated with the Log Analytics cluster.
    - key_version -- The version of the key associated with the Log Analytics cluster.
    - sku_capacity -- The capacity of the SKU. It must be in the range of 1000-2000 per day and must be in multiples of 100. If you want to increase the limit, please contact LAIngestionRate@microsoft.com. It can be decreased only after 31 days.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az monitor log-analytics cluster update", locals())


def show(name, resource_group):
    '''
    Show the properties of a cluster instance.

    Required Parameters:
    - name -- The name of the Log Analytics cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor log-analytics cluster show", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete a cluster instance.

    Required Parameters:
    - name -- The name of the Log Analytics cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az monitor log-analytics cluster delete", locals())


def list(resource_group=None):
    '''
    Gets all cluster instances in a resource group or in current subscription.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor log-analytics cluster list", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the cluster is met.

    Required Parameters:
    - name -- The name of the Log Analytics cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az monitor log-analytics cluster wait", locals())

